==> shuncommands-1.0.2.tar.gz: shuncommands-1.0.2/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [1.0.2](https://github.com/mypaceshun/shuncommands/releases/tag/1.0.2) - 2021-12-15

<small>[Compare with 1.0.1](https://github.com/mypaceshun/shuncommands/compare/1.0.1...1.0.2)</small>


## [1.0.1](https://github.com/mypaceshun/shuncommands/releases/tag/1.0.1) - 2021-12-15

<small>[Compare with 1.0.0](https://github.com/mypaceshun/shuncommands/compare/1.0.0...1.0.1)</small>

### Changed
- Changed: [rmtmp] day option is reuiqred set over 0 ([f24a601](https://github.com/mypaceshun/shuncommands/commit/f24a60135279a3f29c7ba62a35844bfd55e37c29) by KAWAI Shun).
- Changed: [rmtmp] not remove .rmtmpignore ([4099e30](https://github.com/mypaceshun/shuncommands/commit/4099e303bdbdf21c98c466b186e4fddf9e70c815) by KAWAI Shun).


## [1.0.0](https://github.com/mypaceshun/shuncommands/releases/tag/1.0.0) - 2021-12-08

<small>[Compare with 0.9.2](https://github.com/mypaceshun/shuncommands/compare/0.9.2...1.0.0)</small>

### Added
- Add new command pdftool ([25962f0](https://github.com/mypaceshun/shuncommands/commit/25962f00510c89de4759879312478121ccb50582) by KAWAI Shun).


## [0.9.2](https://github.com/mypaceshun/shuncommands/releases/tag/0.9.2) - 2021-12-08

<small>[Compare with first commit](https://github.com/mypaceshun/shuncommands/compare/f527f4ecc9382eff95095f764a05ab58ec2b2a92...0.9.2)</small>

### Added
- Add new command rmtmp ([4f0d520](https://github.com/mypaceshun/shuncommands/commit/4f0d520364f5bde39763b0836320e8df17ca9638) by KAWAI Shun).

==> shuncommands-1.0.4a0.tar.gz: shuncommands-1.0.4a0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [1.0.3](https://github.com/mypaceshun/shuncommands/releases/tag/1.0.3) - 2021-12-15

<small>[Compare with 1.0.2](https://github.com/mypaceshun/shuncommands/compare/1.0.2...1.0.3)</small>


## [1.0.2](https://github.com/mypaceshun/shuncommands/releases/tag/1.0.2) - 2021-12-15

<small>[Compare with 1.0.1](https://github.com/mypaceshun/shuncommands/compare/1.0.1...1.0.2)</small>


## [1.0.1](https://github.com/mypaceshun/shuncommands/releases/tag/1.0.1) - 2021-12-15

<small>[Compare with 1.0.0](https://github.com/mypaceshun/shuncommands/compare/1.0.0...1.0.1)</small>

### Changed
- Changed: [rmtmp] day option is reuiqred set over 0 ([f24a601](https://github.com/mypaceshun/shuncommands/commit/f24a60135279a3f29c7ba62a35844bfd55e37c29) by KAWAI Shun).
- Changed: [rmtmp] not remove .rmtmpignore ([4099e30](https://github.com/mypaceshun/shuncommands/commit/4099e303bdbdf21c98c466b186e4fddf9e70c815) by KAWAI Shun).


## [1.0.0](https://github.com/mypaceshun/shuncommands/releases/tag/1.0.0) - 2021-12-08

<small>[Compare with 0.9.2](https://github.com/mypaceshun/shuncommands/compare/0.9.2...1.0.0)</small>

### Added
- Add new command pdftool ([25962f0](https://github.com/mypaceshun/shuncommands/commit/25962f00510c89de4759879312478121ccb50582) by KAWAI Shun).


## [0.9.2](https://github.com/mypaceshun/shuncommands/releases/tag/0.9.2) - 2021-12-08

<small>[Compare with first commit](https://github.com/mypaceshun/shuncommands/compare/f527f4ecc9382eff95095f764a05ab58ec2b2a92...0.9.2)</small>

### Added
- Add new command rmtmp ([4f0d520](https://github.com/mypaceshun/shuncommands/commit/4f0d520364f5bde39763b0836320e8df17ca9638) by KAWAI Shun).
